@@ -62,7 +62,7 @@ class FortranBackend(BaseBackend):
                  imports: Optional[List[str]] = None,
                  **kwargs
                  ) -> None:
-        """Instantiates tensorflow backend, i.e. a tensorflow graph.
+        """Instantiates Fortran backend.
         """
 
         # add user-provided operations to function dict
@@ -96,7 +96,7 @@ class FortranBackend(BaseBackend):
         else:
             return super().create_index_str(idx, separator, apply, **kwargs)
 
-    def generate_func_head(self, func_name: str, state_var: str = None, func_args: list = None):
+    def generate_func_head(self, func_name: str, state_var: str = 'y', return_var: str = 'dy', func_args: list = None):
 
         # finalize list of arguments for the function call
         if func_args:
@@ -123,7 +123,7 @@ class FortranBackend(BaseBackend):
 
         # add function header
         self.add_linebreak()
-        self._add_func_call(name=func_name, args=func_args)
+        self._add_func_call(name=func_name, args=func_args, return_var=return_var)
 
         return func_args
 
@@ -264,7 +264,7 @@ class FortranBackend(BaseBackend):
         return expr
 
     def _generate_auto_files(self, func_name: str, func_args: tuple = (), state_vars: tuple = (),
-                             blocked_indices: tuple = (10, 32), **kwargs):
+                             blocked_indices: tuple = (10, 15), **kwargs):
 
         # wrapper to the right-hand side evaluation function
         ####################################################
@@ -292,6 +292,7 @@ class FortranBackend(BaseBackend):
         for i, arg in enumerate(func_args):
             idx = i + increment
             if blocked_indices[0] <= idx <= blocked_indices[1]:
+                idx -= increment
                 increment += blocked_indices[1] - blocked_indices[0]
                 idx += increment
             params.append(f'args({idx})')
@@ -322,6 +323,7 @@ class FortranBackend(BaseBackend):
         for i, arg in enumerate(func_args):
             idx = i + increment
             if blocked_indices[0] <= idx <= blocked_indices[1]:
+                idx -= increment
                 increment += blocked_indices[1] - blocked_indices[0]
                 idx += increment
             p = self._var_declaration_info[arg]
@@ -405,7 +407,7 @@ class FortranBackend(BaseBackend):
 
         return func_info
 
-    def _add_func_call(self, name: str, args: Iterable):
+    def _add_func_call(self, name: str, args: Iterable, return_var: str = 'dy'):
 
         # add function header
         self.add_code_line(f"subroutine {name}({','.join(args)})")
