@@ -52,7 +52,7 @@ class AbstractBaseTemplate:
 
     @classmethod
     def from_yaml(cls, path):
-        """Short hand to load a template from yaml file. After importing the template, this method also checks whether
+        """Load a template from yaml file. After importing the template, this method also checks whether
         the resulting template is actually an instance of the class that this method was called from. This is done to
         ensure any cls.from_yaml() produces only instances of that class and not other classes for consistency.
         Templates are cached by path. Depending on the 'base' key of the yaml template,
@@ -81,6 +81,10 @@ class AbstractBaseTemplate:
         else:
             raise TypeError(f"The template associated with '{path}' is not of type {cls}.")
 
+    def to_yaml(self, path, **kwargs) -> None:
+        """Saves template to YAML file."""
+        raise NotImplementedError
+
     def update_template(self, *args, **kwargs):
         """Updates the template with a given list of arguments and returns a new instance of the template class."""
         raise NotImplementedError
