@@ -440,13 +440,13 @@ def test_2_6_vectorization():
 
         # simulation without vectorization of the network equations
         r1 = integrate("model_templates.neural_mass_models.jansenrit.JRC_2delaycoupled", vectorize=False,
-                       inputs={"jrc2/pc/rpo_e_in/u": inp}, outputs={"r": "jrc1/ein/rpo_e/V"}, backend=b,
+                       inputs={"jrc2/pc/rpo_e_in/u": inp}, outputs={"r": "jrc1/ein/rpo_e/v"}, backend=b,
                        solver='euler', step_size=dt, clear=True, simulation_time=T, sampling_step_size=dts,
                        file_name=f'novec{i + 1}')
 
         # simulation with vectorized network equations
         r2 = integrate("model_templates.neural_mass_models.jansenrit.JRC_2delaycoupled", vectorize=True,
-                       inputs={"jrc2/pc/rpo_e_in/u": inp}, outputs={"r": "jrc1/ein/rpo_e/V"}, backend=b,
+                       inputs={"jrc2/pc/rpo_e_in/u": inp}, outputs={"r": "jrc1/ein/rpo_e/v"}, backend=b,
                        solver='euler', step_size=dt, clear=True, simulation_time=T, sampling_step_size=dts,
                        file_name=f'vec{i + 1}')
 
